@@ -216,7 +216,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response.raise_for_status()
         r = response.json()
 
-    def load_dataset(self, datasetSlug):
+    def _load_dataset(self, datasetSlug):
 
         dataset = self.get_dataset_by_slug(self._agentId, datasetSlug)
 
@@ -234,6 +234,80 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r = response.json()
         return pd.DataFrame(r['payload']['data'])
 
+    def load_dataset(self, dataset_slug, aliases:list=[], filters:list=[]):
+
+        '''
+        str : dataset_slug ("my_dataset")
+        list : aliases (["alias of the column", "column 2"])
+        list : filters ([{field: {column: "CONTACTS", alias: null, aggregation: null,…}, operator: "EQ", type: "NUMERIC",…}])
+        '''
+
+        dataset = self.get_dataset_by_slug(self._agentId, dataset_slug)
+
+        if(aliases==[]):
+            return self._load_dataset(dataset_slug)
+
+        dataset_id = dataset["id"]
+        url_get = self.smart_insight_url + "/composed_queries?datasetId=" + dataset_id
+
+        logging.info("CALLING {}".format(url_get))
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.get(url=url_get, headers=headers)
+        response.raise_for_status()
+        r = response.json()
+
+        qc_id = r["qc"]["id"]
+        logging.info(qc_id)
+
+        body = {
+            "datasets": [{"dataset": dataset_id}],
+            "id": qc_id,
+            "orderBy": None,
+            "relationships": None,
+            "where": filters,
+            "limit": 100
+        }
+        fields = []
+        for alias in aliases:
+            fields.append({"column": str(alias).upper(), "alias": alias, "aggregation": None, "dataset": dataset_id})
+
+        body["fields"] = fields
+
+        url_post = self.smart_insight_url + "/composed_queries"
+
+        logging.info("CALLING {}".format(url_post))
+        logging.info(body)
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.post(url=url_post, json=body, headers=headers)
+        response.raise_for_status()
+
+        preview_url= self.smart_insight_url+"/composed_queries/"+qc_id+"/preview"
+
+        logging.info("CALLING {}".format(preview_url))
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.post(url=preview_url, json={}, headers=headers)
+        response.raise_for_status()
+
+        r = response.json()
+        return pd.DataFrame(r['data'])
+
     def get_dataset_by_slug(self, agent_id, slug: str) -> Dataset:
         s = requests.Session()
         s.keep_alive = False
@@ -366,23 +440,23 @@ class Agent(Insight, Channel, Catalog, Dataset):
             self._update_dataset_icon(dataset_id, icon_url)
 
     '''La prima chiave è la stringa colonna del dataframe. Per ogni chiave ho dei setting:
-    Name stringa
-    Type(dimension o measure)
-    IsDate booleano
-    Synonyms: [] array di stringhe
-    Date(pattern della data)
-    Format
-    DefaultAggreation(sum, avg..)
+    name stringa
+    type(dimension o measure)
+    isDate booleano
+    synonyms: [] array di stringhe
+    dateFormat(pattern della data)
+    numberFormat
+    defaultAggregation(sum, avg..)
 
     {
         "column_name": {
-            "Name": "column_name",
-            "Type": "Dimension",
-            "IsDate": False,
-            "Synonyms": [],
-            "Date",
-            "Format": "",
-            "DefaultAggreation": "sum"
+            "name": "column_name",
+            "type": "Dimension",
+            "isDate": False,
+            "synonyms": [],
+            "dateFormat",
+            "numberFormat": "",
+            "defaultAggregation": "sum"
         }
     }
     '''
