@@ -176,11 +176,135 @@ class Insight_Definition:
         self.components = r.json()["components"]
 
 
-    def add_list(self):
+    def add_list(self, query_id, title_parameter, description_parameter, action_label,
+                  action_url, max_results,list_name="List"):
         position = (len(self.components))
         list_id = self.add_component("list", position)
+        self.edit_list(list_id, query_id, title_parameter,
+                       description_parameter, action_label, action_url, max_results, list_name)
         return list_id
 
+
+    def edit_list(self, list_id, query_id, title_parameter, description_parameter, action_label,
+                  action_url, max_results,list_name="List"):
+
+        url = self.smart_insight_url + "/definitions/" + self.definition_id + "/lists/" + list_id
+        body = {
+            "id":list_id,
+            "type":"list",
+            "name":list_name,
+            "customName":True,
+            "dependsOn":[],
+            "queryId":query_id,
+            "title":title_parameter,
+            "description":description_parameter,
+            "actionEnabled":True,
+            "actionLabel":action_label,
+            "actionUrl":action_url,
+            "maxResults":max_results,
+            "valid":True,
+            "queryComponent":False
+        }
+
+        logging.info("URL: {}".format(url))
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+        self.components = r.json()["components"]
+
+
+    def add_cta(self, cta_label, cta_url):
+        position = (len(self.components))
+        cta_id = self.add_component("cta", position)
+        self.edit_cta(cta_id, cta_label, cta_url)
+        return cta_id
+
+    def edit_cta(self, id, label, cta_url):
+
+        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/ctas/"+id
+        body = {
+            "id":id,
+            "type":"cta",
+            "name":"Cta 1",
+            "customName":False,
+            "dependsOn":[],
+            "valid":True,
+            "queryComponent":False,
+            "label":label,
+            "link":cta_url
+        }
+
+        logging.info("URL: {}".format(url))
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+        self.components = r.json()["components"]
+
+    def add_compare(self, name, second_item_enabled, query_id_1, measure_1, label_1, description_1,
+                     query_id_2, measure_2, label_2, description_2, formatter_type="HIGH"):
+        position = (len(self.components))
+        compare_id = self.add_component("comparison", position)
+        self.edit_compare(compare_id, name, second_item_enabled, query_id_1, measure_1, label_1, description_1,
+                     query_id_2, measure_2, label_2, description_2, formatter_type)
+        return compare_id
+
+    def edit_compare(self, compare_id, name, second_item_enabled, query_id_1, measure_1, label_1, description_1,
+                     query_id_2, measure_2, label_2, description_2, formatter_type="HIGH"):
+
+        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/comparisons/"+compare_id
+        body = {
+            "name": name,
+            "itemA": {
+                "queryId": query_id_1,
+                "measure":measure_1,
+                "label":label_1,
+                "description":description_1,
+                "measureComparator":None
+            },
+            "itemB": {
+                "queryId":query_id_2,
+                "measure":measure_2,
+                "label":label_2,
+                "description": description_2,
+                "measureComparator":None
+            },
+            "secondItemEnabled": second_item_enabled,
+            "formatterType":formatter_type
+        }
+        logging.info("URL: {}".format(url))
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+        self.components = r.json()["components"]
+
+
     def add_text(self, text):
         position = (len(self.components))
         text_id = self.add_component("text", position)
