@@ -41,6 +41,12 @@ class SQLOperator(Enum):
     LT = auto()
     IN = auto()
     NOT_IN = auto()
+    FOREACH = auto()
+
+
+class BooleanOperator(Enum):
+    AND = auto()
+    OR = auto()
 
 
 @dataclass
@@ -50,6 +56,51 @@ class Condition:
     value: List[Union[float, str]]
     type: Optional[str] = None
 
+    def __repr__(self):
+        vars = []
+        for var in self.value:
+            vars.append(str(var))
+        formatted_value = "( " + ", ".join(vars) + " )"
+        if isinstance(self.operator, str):
+            operator = self.operator
+        else:
+            operator = self.operator.name
+            if operator == "GOE":
+                operator = ">="
+            elif operator == "LOE":
+                operator = "<="
+            elif operator == "EQ":
+                operator = "=="
+            elif operator == "GT":
+                operator = ">"
+            elif operator == "LT":
+                operator = "<"
+        field_with_agg = self.field.column
+        if self.field.aggregation is not None:
+            if isinstance(self.field.aggregation, SQLFunction) or isinstance(self.field.aggregation,
+                                                                                  TimeDimensionGranularity):
+                field_with_agg = self.field.aggregation.name + " ( " + field_with_agg + " )"
+            else:
+                field_with_agg = self.field.aggregation + " ( " + field_with_agg + " )"
+        else:
+            field_with_agg = field_with_agg
+        where_condition = (
+                field_with_agg + " " + operator + " " + str(formatted_value)
+        )
+
+        return where_condition
+
+
+@dataclass
+class CompositeCondition:
+    operator: BooleanOperator
+    conditions: List[Union[Condition, 'CompositeCondition']]
+
+    def __repr__(self):
+        where_condition = '( ' + (' ' + self.operator.name + ' ').join([str(c) for c in self.conditions]) + ' )'
+
+        return where_condition
+
 
 class SQLSorting(Enum):
     DESC = auto()
@@ -83,7 +134,7 @@ class Query:
     fields: List[Field]
     id: Optional[str] = None
     datasets: Optional[List[From]] = None
-    where: Optional[List[Condition]] = None
+    where: Optional[List[Union[Condition, CompositeCondition]]] = None
     orderBy: Optional[List[Sorting]] = None
     limit: Optional[Union[int, str]] = None
 
@@ -122,35 +173,7 @@ class Query:
             sql_where = " WHERE {}"
 
             for condition in self.where:
-                vars = []
-                for var in condition.value:
-                    vars.append(str(var))
-                formatted_value = "( " + ", ".join(vars) + " )"
-                if isinstance(condition.operator, str):
-                    operator = condition.operator
-                else:
-                    operator = condition.operator.name
-                    if operator == "GOE":
-                        operator = ">="
-                    elif operator == "LOE":
-                        operator = "<="
-                    elif operator == "EQ":
-                        operator = "=="
-                    elif operator == "GT":
-                        operator = ">"
-                    elif operator == "LT":
-                        operator = "<"
-                field_with_agg = condition.field.column
-                if condition.field.aggregation is not None:
-                    if isinstance(condition.field.aggregation, SQLFunction) or isinstance(condition.field.aggregation, TimeDimensionGranularity):
-                        field_with_agg = condition.field.aggregation.name + " ( " + field_with_agg + " )"
-                    else:
-                        field_with_agg = condition.field.aggregation + " ( " + field_with_agg + " )"
-                else:
-                    field_with_agg = field_with_agg
-                where_condition = (
-                        field_with_agg + " " + operator + " " + str(formatted_value)
-                )
+                where_condition = str(condition)
                 where_conditions.append(where_condition)
             if where_conditions:
                 formatted_where_conditions = " AND ".join(where_conditions)
